@@ -20,15 +20,16 @@ except ImportError: #pragma: no cover
     class WidgetMeta(object):
         """TW2 WidgetMetaClass"""
 
+
 import inspect
 from sprox.util import name2label, is_widget, is_widget_class
 
-from sprox.widgets import SproxMethodPutHiddenField, CalendarDatePicker, CalendarDateTimePicker
+from sprox.widgets import SproxMethodPutHiddenField, CalendarBase, CalendarDatePicker, CalendarDateTimePicker
 from .viewbase import ViewBase, ViewBaseError
 from formencode import Schema, All
 from formencode import Validator
 from formencode.validators import String
-from sprox.validators import UnicodeString
+from sprox.validators import UnicodeString, NotEmpty
 
 from sprox.validators import UniqueValue
 from sprox.metadata import FieldsMetadata
@@ -300,7 +301,7 @@ class FormBase(ViewBase):
         """
         v_type = self.__field_validator_types__.get(field_name, self.__validator_selector__[field])
         if field_name in self.__require_fields__ and v_type is None:
-            v_type = UnicodeString
+            v_type = NotEmpty
         if v_type is None:
             return
         args = self._do_get_validator_args(field_name, field, v_type)
@@ -318,7 +319,8 @@ class FormBase(ViewBase):
         args['required'] = args['not_empty']
 
         widget_type = self._do_get_field_widget_type(field_name, field)
-        if widget_type and (issubclass(widget_type, CalendarDatePicker) or
+        if widget_type and (issubclass(widget_type, CalendarBase) or
+                            issubclass(widget_type, CalendarDatePicker) or
                             issubclass(widget_type, CalendarDateTimePicker)):
             widget_args = super(FormBase, self)._do_get_field_widget_args(field_name, field)
             args['format'] = widget_args.get('date_format', widget_type.date_format)
