@@ -1,7 +1,7 @@
-from viewbase import ViewBase
-from metadata import FieldsMetadata
-from widgetselector import RecordViewWidgetSelector
-from widgets import RecordViewWidget
+from .viewbase import ViewBase
+from .metadata import FieldsMetadata
+from .widgetselector import RecordViewWidgetSelector
+from .widgets import RecordViewWidget
 
 class RecordViewBase(ViewBase):
     """This class allows you to create a view for a single record.
@@ -24,7 +24,7 @@ class RecordViewBase(ViewBase):
     ...     __model__ = User
     >>> user_filler = UserRecordFiller(session)
     >>> value = user_filler.get_value({'user_id':1})
-    >>> print user_view(value=value)
+    >>> print(user_view(value=value))
     <table>
     <tr><th>Name</th><th>Value</th></tr>
     <tr class="recordfieldwidget" id="sx__password">
@@ -108,4 +108,4 @@ class RecordViewBase(ViewBase):
         if self.__provider__.is_relation(self.__entity__, field_name):
             args['entity'] = self.__entity__
             args['field_name'] = field_name
-        return args
\ No newline at end of file
+        return args
